import _plotly_utils.basevalidators


class LabelaliasValidator(_plotly_utils.basevalidators.AnyValidator):
    def __init__(self, plotly_name="labelalias", parent_name="cone.colorbar", **kwargs):
        super(LabelaliasValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "colorbars"),
            **kwargs,
        )



import sys
from typing import TYPE_CHECKING

if sys.version_info < (3, 7) or TYPE_CHECKING:
    from ._bounds import Bounds
    from ._center import Center
    from ._domain import Domain
    from ._layer import Layer
    from . import layer
else:
    from _plotly_utils.importers import relative_import

    __all__, __getattr__, __dir__ = relative_import(
        __name__,
        [".layer"],
        ["._bounds.Bounds", "._center.Center", "._domain.Domain", "._layer.Layer"],
    )



import _plotly_utils.basevalidators


class MatchesValidator(_plotly_utils.basevalidators.BooleanValidator):
    def __init__(
        self, plotly_name="matches", parent_name="splom.dimension.axis", **kwargs
    ):
        super(MatchesValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "calc"),
            **kwargs,
        )



import _plotly_utils.basevalidators


class LegendValidator(_plotly_utils.basevalidators.SubplotidValidator):
    def __init__(
        self, plotly_name="legend", parent_name="histogram2dcontour", **kwargs
    ):
        super(LegendValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            dflt=kwargs.pop("dflt", "legend"),
            edit_type=kwargs.pop("edit_type", "style"),
            **kwargs,
        )



import _plotly_utils.basevalidators


class YrefValidator(_plotly_utils.basevalidators.EnumeratedValidator):
    def __init__(self, plotly_name="yref", parent_name="layout.legend", **kwargs):
        super(YrefValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "layoutstyle"),
            values=kwargs.pop("values", ["container", "paper"]),
            **kwargs,
        )



import _plotly_utils.basevalidators


class SideValidator(_plotly_utils.basevalidators.EnumeratedValidator):
    def __init__(self, plotly_name="side", parent_name="cone.colorbar.title", **kwargs):
        super(SideValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "colorbars"),
            values=kwargs.pop("values", ["right", "top", "bottom"]),
            **kwargs,
        )



import _plotly_utils.basevalidators


class MinreducedheightValidator(_plotly_utils.basevalidators.NumberValidator):
    def __init__(self, plotly_name="minreducedheight", parent_name="layout", **kwargs):
        super(MinreducedheightValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "plot"),
            min=kwargs.pop("min", 2),
            **kwargs,
        )



import _plotly_utils.basevalidators


class IconValidator(_plotly_utils.basevalidators.StringValidator):
    def __init__(
        self, plotly_name="icon", parent_name="layout.mapbox.layer.symbol", **kwargs
    ):
        super(IconValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "plot"),
            **kwargs,
        )



import sys
from typing import TYPE_CHECKING

if sys.version_info < (3, 7) or TYPE_CHECKING:
    from ._t import TValidator
    from ._r import RValidator
    from ._l import LValidator
    from ._b import BValidator
else:
    from _plotly_utils.importers import relative_import

    __all__, __getattr__, __dir__ = relative_import(
        __name__,
        [],
        ["._t.TValidator", "._r.RValidator", "._l.LValidator", "._b.BValidator"],
    )



from ._version import get_versions

__version__ = get_versions()["version"]
del get_versions

from ._widget_version import __frontend_version__


def stable_semver():
    """
    Get the stable portion of the semantic version string (the first three
    numbers), without any of the trailing labels

    '3.0.0rc11' -> '3.0.0'
    """
    from packaging.version import Version

    return Version(__version__).base_version
